/*
 *   Copyright 2017-2020, Schlumberger
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.opengroup.osdu.notification.auth;

import org.opengroup.osdu.core.common.cryptographic.ISignatureService;
import org.opengroup.osdu.core.common.model.notification.HmacSecret;
import org.opengroup.osdu.core.common.model.notification.Secret;
import org.opengroup.osdu.notification.auth.interfaces.SecretAuth;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.annotation.RequestScope;

import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

@Component
public class HmacAuth implements SecretAuth {
    @Autowired
    private ISignatureService signatureService;

    private HmacSecret hmacSecret;

    public void setSecret(Secret secret) {
        this.hmacSecret = (HmacSecret) secret;
    }

    public Secret getSecret() {
        return this.hmacSecret;
    }

    public String getPushUrl(String endpoint) throws Exception {
        String signedjwt = this.signatureService.getSignedSignature(endpoint, hmacSecret.getValue());
        return String.format("%s?hmac=%s", endpoint, URLEncoder.encode(signedjwt, StandardCharsets.UTF_8));
    }

    public Map<String, String> getRequestHeaders() {
        Map<String, String> requestHeader = new HashMap<>();
        return requestHeader;

    }
}
