// Copyright © Schlumberger
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.utils;

import org.opengroup.osdu.core.common.http.HttpResponse;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.Request;
import org.opengroup.osdu.core.common.model.notification.Subscription;
import org.opengroup.osdu.notification.provider.interfaces.ISubscriberNotificationRequestLogger;
import org.springframework.stereotype.Component;

import java.time.Duration;

@Component
public class DefaultSubscriberNotificationRequestLogger implements ISubscriberNotificationRequestLogger {

    private JaxRsDpsLog logger;

    public DefaultSubscriberNotificationRequestLogger(JaxRsDpsLog logger) {
        this.logger = logger;
    }

    public void log(String notificationId, Subscription subscription, HttpResponse response) {
        this.logger.request("subscriber.request", Request.builder()
                .requestMethod("POST")
                .latency(Duration.ofMillis(response.getLatency()))
                .requestUrl(subscription.getPushEndpoint())
                .Status(response.getResponseCode())
                .build());

        if (!response.isSuccessCode()) {
            this.logger.error(String.format("Subscriber notification request failed. notificationId=%s subscriptionId=%s createdBy=%s response=%s", notificationId, subscription.getId(), subscription.getCreatedBy(), response.getBody()));
        }
    }
}
