// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.di;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.common.model.tenant.TenantInfo;
import org.opengroup.osdu.core.common.multitenancy.PartitionTenantInfoFactory;
import org.springframework.test.util.ReflectionTestUtils;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class SubscriptionCacheFactoryTest {

    SubscriptionCacheFactory subscriptionCacheFactory;

    @Mock
    private DpsHeaders headers;

    @Mock
    private PartitionTenantInfoFactory tenantFactory;

    @Mock
    private TenantInfo tenantInfo;

    @Before
    public void setup() {
        subscriptionCacheFactory = new SubscriptionCacheFactory(1234567, 1000);
        MockitoAnnotations.initMocks(SubscriptionCacheFactoryTest.this);
        ReflectionTestUtils.setField(subscriptionCacheFactory, "headers", headers);
        ReflectionTestUtils.setField(subscriptionCacheFactory, "tenantFactory", tenantFactory);
        tenantInfo.setDataPartitionId("opendes");
        when(tenantFactory.getTenantInfo(any())).thenReturn(tenantInfo);
        when(headers.getPartitionIdWithFallbackToAccountId()).thenReturn("opendes");
        when(tenantInfo.getDataPartitionId()).thenReturn("opendes");
        subscriptionCacheFactory.put("testKey", "testVal");
    }

    @Test
    public void getTest() {
        String actual = subscriptionCacheFactory.get("testKey");
        assertEquals("testVal", actual);
    }

    @Test
    public void deleteTest() {
        subscriptionCacheFactory.delete("testKey");
        assertNull(subscriptionCacheFactory.get("testKey"));
    }

    @Test
    public void clearAll() {
        subscriptionCacheFactory.clearAll();
        assertNull(subscriptionCacheFactory.get("testKey"));
    }
}