// Copyright © Amazon Web Services
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package org.opengroup.osdu.notification.provider.aws.model;

import com.amazonaws.services.dynamodbv2.datamodeling.DynamoDBAttribute;
import com.amazonaws.services.dynamodbv2.datamodeling.DynamoDBHashKey;
import com.amazonaws.services.dynamodbv2.datamodeling.DynamoDBIndexHashKey;
import com.amazonaws.services.dynamodbv2.datamodeling.DynamoDBTable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.opengroup.osdu.core.common.model.notification.Secret;
import org.opengroup.osdu.core.common.model.notification.Subscription;

import java.nio.ByteBuffer;

@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@DynamoDBTable(tableName = "Register.Subscription")
public class SubscriptionDoc {

    @DynamoDBHashKey(attributeName = "id")
    private String id;

    @DynamoDBAttribute(attributeName = "name")
    private String name;

    @DynamoDBAttribute(attributeName = "description")
    private String description;

    @DynamoDBAttribute(attributeName = "topic")
    private String topic;

    @DynamoDBAttribute(attributeName = "pushEndpoint")
    private String pushEndpoint;

    @DynamoDBAttribute(attributeName = "createdBy")
    private String createdBy;

    @DynamoDBAttribute(attributeName = "createdOnEpoch")
    private String createdOnEpoch;

    @DynamoDBAttribute(attributeName = "notificationId")
    private String notificationId;

    @DynamoDBAttribute(attributeName = "secretType")
    private String secretType;

    @DynamoDBAttribute(attributeName = "secretValue")
    private ByteBuffer secretValue;

    @DynamoDBIndexHashKey(attributeName = "dataPartitionId", globalSecondaryIndexName = "dataPartitionId-index")
    private String dataPartitionId;

    public static Subscription mapTo(SubscriptionDoc subDoc, Secret secret) {
        Subscription sub = new Subscription();
        sub.setId(subDoc.getId());
        sub.setName(subDoc.getName());
        sub.setDescription(subDoc.getDescription());
        sub.setTopic(subDoc.getTopic());
        sub.setPushEndpoint(subDoc.getPushEndpoint());
        sub.setCreatedBy(subDoc.getCreatedBy());
        sub.setNotificationId(subDoc.getNotificationId());
        sub.setSecret(secret);

        return sub;
    }


}
