package org.opengroup.osdu.notification.provider.aws.utils;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.when;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import com.amazonaws.services.cognitoidp.AWSCognitoIdentityProvider;
import com.amazonaws.services.sqs.AmazonSQS;

import io.jsonwebtoken.lang.Assert;

@RunWith(MockitoJUnitRunner.class)
public class AwsCognitoClientTest {

	private AwsCognitoClient awsCognitoClient;

	@Mock
	private AmazonSQS sqsClient;

	@Mock
	private AWSCognitoIdentityProvider provider;

	@Before
	public void setUp() {
		awsCognitoClient = new AwsCognitoClient("region", "awsCognitoClientId", "awsCognitoAuthFlow",
				"awsCognitoAuthParamsUser", "awsCognitoAuthParamsPassword");
	}

	@Test
	public void constuctorCreatesObject() {
		Assert.isInstanceOf(AwsCognitoClient.class, awsCognitoClient);
		assertNotNull(awsCognitoClient);
	}

	@Test
	public void getToken() {
		awsCognitoClient.provider = provider;
		when(provider.initiateAuth(any())).thenReturn(null);
		String expected = "";
		String actual = awsCognitoClient.getToken("username", "password", "tokenType");
		assertEquals(expected, actual);
	}
	
	@Test
	public void getProvider() {
		AWSCognitoIdentityProvider object = awsCognitoClient.getProvider();
		assertTrue(object instanceof AWSCognitoIdentityProvider);
	}
	
	@Test
	public void generateCognitoClient() {
		AWSCognitoIdentityProvider object = awsCognitoClient.generateCognitoClient("us-east-1");
		assertTrue(object instanceof AWSCognitoIdentityProvider);
	}
	
	//the code on production side seems useless. hence useless test here just for coverage.
	@Test
	public void setPassword() {
		awsCognitoClient.provider = provider;
		when(provider.adminSetUserPassword(any())).thenReturn(null);
		awsCognitoClient.setPassword("username", "password", "user-pool-id");
		assertNotNull(awsCognitoClient);
	}
}
