// Copyright © Amazon Web Services
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package org.opengroup.osdu.notification.provider.aws.utils;

import static org.junit.Assert.assertEquals;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.when;

import com.amazonaws.services.sqs.AmazonSQS;
import com.amazonaws.services.sqs.model.DeleteMessageBatchRequest;
import com.amazonaws.services.sqs.model.DeleteMessageBatchResult;
import com.amazonaws.services.sqs.model.DeleteMessageBatchResultEntry;
import com.amazonaws.services.sqs.model.Message;
import com.amazonaws.services.sqs.model.ReceiveMessageRequest;
import com.amazonaws.services.sqs.model.ReceiveMessageResult;
import com.amazonaws.services.sqs.model.SendMessageRequest;
import com.amazonaws.services.sqs.model.SendMessageResult;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@RunWith(MockitoJUnitRunner.class)
public class SQSUtilsTest {

    @Mock
    private AmazonSQS sqsClient;

    @InjectMocks
    SQSUtils sqsUtils;

    @Test
    public void getMessages_success() {
        ReceiveMessageResult sqsResult = new ReceiveMessageResult();
        Message message1 = new Message();
        sqsResult.setMessages(Arrays.asList(message1));

        when(sqsClient.receiveMessage(any(ReceiveMessageRequest.class))).thenReturn(sqsResult);
        List<Message> response = sqsUtils.getMessages(sqsClient, "test-sqs-url", 10, 10);
        assertEquals(10, response.size());
    }


    @Test
    public void deleteMessages_success() {
        DeleteMessageBatchResult deleteResult = new DeleteMessageBatchResult();
        List<DeleteMessageBatchResultEntry> deleteEntries = new ArrayList<>();
        deleteEntries.add(new DeleteMessageBatchResultEntry());
        deleteResult.setSuccessful(deleteEntries);

        Message message1 = new Message();

        when(sqsClient.deleteMessageBatch(any(DeleteMessageBatchRequest.class))).thenReturn(deleteResult);
        int deletedCount = sqsUtils.deleteMessages(Arrays.asList(message1), "test-sqs-url", sqsClient);
        assertEquals(1, deletedCount);
    }

    @Test
    public void sendMessagesToDeadLetterQueue_success() {
        SendMessageResult sendResult = new SendMessageResult();

        Message message1 = new Message();

        when(sqsClient.sendMessage(any(SendMessageRequest.class))).thenReturn(sendResult);
        List<SendMessageResult> results = sqsUtils.sendMessagesToDeadLetterQueue("test-deadletter-sqs-url", Arrays.asList(message1), sqsClient);
        assertEquals(1, results.size());
    }
}
