// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.util;


import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.azure.util.AzureServicePrincipleTokenService;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.notification.provider.azure.util.ServiceAccountJwtAzureClientImpl;

import java.io.UnsupportedEncodingException;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;
import static org.mockito.Mockito.times;

@RunWith(MockitoJUnitRunner.class)
public class ServiceAccountClientImplTest {

    private static final  String tenantId = "tenantId";
    private static final String token = "jwt-token";

    @InjectMocks
    private ServiceAccountJwtAzureClientImpl serviceAccountJwtAzureClient;

    @Mock
    private AzureServicePrincipleTokenService azureServicePrincipleTokenService;

    @Test
    public void shouldSuccessfullyGenerateToken() throws UnsupportedEncodingException {

        when(azureServicePrincipleTokenService.getAuthorizationToken()).thenReturn(token);

        String result = serviceAccountJwtAzureClient.getIdToken(tenantId);

        assertEquals("Bearer " + token, result);
        verify(azureServicePrincipleTokenService, times(1)).getAuthorizationToken();
    }

    @Test
    public void shouldThrowAppException() throws UnsupportedEncodingException {

        doThrow(AppException.class).when(azureServicePrincipleTokenService).getAuthorizationToken();

        AppException exception = assertThrows(AppException.class, () -> {
            serviceAccountJwtAzureClient.getIdToken(tenantId);
        });

        assertNotNull(exception);
        verify(azureServicePrincipleTokenService, times(1)).getAuthorizationToken();
    }
}

