/*
 *  Copyright 2020-2023 Google LLC
 *  Copyright 2020-2023 EPAM Systems, Inc
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.opengroup.osdu.notification.provider.gcp.config;

import lombok.RequiredArgsConstructor;
import org.opengroup.osdu.core.common.cache.ICache;
import org.opengroup.osdu.core.common.cache.IRedisCache;
import org.opengroup.osdu.core.common.cache.VmCache;
import org.opengroup.osdu.core.common.partition.PartitionInfo;
import org.opengroup.osdu.core.gcp.cache.RedisCacheBuilder;
import org.opengroup.osdu.notification.provider.gcp.model.ExternalSubscriptions;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
@RequiredArgsConstructor
public class CacheConfig {

    private final RedisCacheBuilder<String, ExternalSubscriptions> builder;

    @Bean
    public IRedisCache<String, ExternalSubscriptions> subscriptionCache(RedisProperties properties) {
        return builder.buildRedisCache(
                properties.getRedisHost(),
                properties.getRedisPort(),
                properties.getRedisPassword(),
                properties.getRedisExpiration(),
                properties.getRedisWithSsl(),
                String.class,
                ExternalSubscriptions.class
        );
    }

  @Bean
  public ICache<String, PartitionInfo> partitionInfoCache() {
    return new VmCache<>(600, 2000);
  }
}