/*
 *  Copyright 2020-2022 Google LLC
 *  Copyright 2020-2022 EPAM Systems, Inc
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.opengroup.osdu.notification.provider.gcp.service;

import lombok.RequiredArgsConstructor;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.common.util.IServiceAccountJwtClient;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

/**
 * DpsHeadersProvider extracts headers from pubsub message
 * to support DpsHeaders usage without RequestScope.
 */
@Component
@RequiredArgsConstructor
public class DpsHeadersProvider {

    private final IServiceAccountJwtClient serviceAccountJwtClient;

    public DpsHeaders getDpsHeaders(String dataPartitionId) {
        Map<String, String> attributes = new HashMap<>();
        attributes.put(DpsHeaders.DATA_PARTITION_ID, dataPartitionId);
        return getDpsHeaders(attributes);
    }

    public DpsHeaders getDpsHeaders(Map<String, String> headerAttributes) {
        Map<String, String> attributes = new HashMap<>(headerAttributes);

        String dataPartitionId = headerAttributes.get(DpsHeaders.DATA_PARTITION_ID);
        String authToken = this.serviceAccountJwtClient.getIdToken(dataPartitionId);
        attributes.put(DpsHeaders.AUTHORIZATION, authToken);
        return DpsHeaders.createFromMap(attributes);
    }
}