package org.opengroup.osdu.notification.subscriptions;

import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.ClientResponse;
import com.sun.jersey.api.client.WebResource;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;

import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import javax.ws.rs.core.MediaType;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.net.HttpURLConnection;
import java.net.URL;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;
import java.util.*;

public class StorageTestUtils {

    public static ClientResponse send(String path, String httpMethod, Map<String, String> headers, String requestBody,
                                      String query) throws Exception {

        log(httpMethod, StorageTestUtils.getApiPath(path + query), headers, requestBody);
        Client client = StorageTestUtils.getClient();

        WebResource webResource = client.resource(StorageTestUtils.getApiPath(path + query));

        WebResource.Builder builder = webResource.accept(MediaType.APPLICATION_JSON).type(MediaType.APPLICATION_JSON);
        headers.forEach(builder::header);

        return builder.method(httpMethod, ClientResponse.class, requestBody);
    }

    public static ClientResponse send(String url, String path, String httpMethod, Map<String, String> headers,
                                      String requestBody, String query) throws Exception {

        log(httpMethod, url + path, headers, requestBody);
        Client client = StorageTestUtils.getClient();

        WebResource webResource = client.resource(url + path);
        WebResource.Builder builder = webResource.accept(MediaType.APPLICATION_JSON).type(MediaType.APPLICATION_JSON);
        headers.forEach(builder::header);

        return builder.method(httpMethod, ClientResponse.class, requestBody);
    }

    private static void log(String method, String url, Map<String, String> headers, String body) {
        System.out.println(String.format("%s: %s", method, url));
        System.out.println(body);
    }

    public static String getApiPath(String api) throws Exception {
        String baseUrl = System.getProperty("STORAGE_URL", System.getenv("STORAGE_URL"));
        URL mergedURL = new URL(baseUrl + api);
        System.out.println(mergedURL.toString());
        return mergedURL.toString();
    }

    protected static Client getClient() {
        TrustManager[] trustAllCerts = new TrustManager[]{new X509TrustManager() {
            @Override
            public X509Certificate[] getAcceptedIssuers() {
                return null;
            }

            @Override
            public void checkClientTrusted(X509Certificate[] certs, String authType) {
            }

            @Override
            public void checkServerTrusted(X509Certificate[] certs, String authType) {
            }
        }};

        try {
            SSLContext sc = SSLContext.getInstance("TLS");
            sc.init(null, trustAllCerts, new SecureRandom());
            HttpsURLConnection.setDefaultSSLSocketFactory(sc.getSocketFactory());
        } catch (Exception e) {
        }
        allowMethods("PATCH");
        return Client.create();
    }

    private static void allowMethods(String... methods) {
        try {
            Field methodsField = HttpURLConnection.class.getDeclaredField("methods");

            Field modifiersField = Field.class.getDeclaredField("modifiers");
            modifiersField.setAccessible(true);
            modifiersField.setInt(methodsField, methodsField.getModifiers() & ~Modifier.FINAL);

            methodsField.setAccessible(true);

            String[] oldMethods = (String[]) methodsField.get(null);
            Set<String> methodsSet = new LinkedHashSet<>(Arrays.asList(oldMethods));
            methodsSet.addAll(Arrays.asList(methods));
            String[] newMethods = methodsSet.toArray(new String[0]);

            methodsField.set(null/*static field*/, newMethods);
        } catch (NoSuchFieldException | IllegalAccessException e) {
            throw new IllegalStateException(e);
        }
    }

    public static Map<String, String> getHeaders(String tenantName, String token, String correlationId, boolean isTestPartition) {
        Map<String, String> headers = new HashMap<>();
        if(tenantName == null || tenantName.isEmpty()) {
            tenantName = TenantUtils.getTenantName(false);
        }
        headers.put("data-partition-id", TenantUtils.getTenantName(isTestPartition));
        headers.put("Authorization", token);

        System.out.printf("Using correlation-id for the request: %s \n", correlationId);
        headers.put("correlation-id", correlationId);
        return headers;
    }
}
